Method: Ensql::Adapter#literalize
- Defined in:
- lib/ensql/adapter.rb
#literalize(value) ⇒ String
Convert a Ruby object into a string that can be safely interpolated into an SQL statement. Strings will be correctly quoted. The precise result will depend on the adapter and the underlying database driver, but most RDBMs have limited ways to express literals.
|
|
# File 'lib/ensql/adapter.rb', line 57
|